function [ret,x0,str,ts,xts]=dcfuzzy(t,x,u,flag);
%DCFUZZY	is the M-file description of the SIMULINK system named DCFUZZY.
%	The block-diagram can be displayed by typing: DCFUZZY.
%
%	SYS=DCFUZZY(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DCFUZZY to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DCFUZZY with a FLAG of zero:
%	[SIZES]=DCFUZZY([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[284,373,1004,748])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'T')
set_param(sys,'Min step size', '0.05')
set_param(sys,'Max step size', '0.5')
set_param(sys,'Relative error','1e-6')
set_param(sys,'Return vars',   '')

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator1']])
set_param([sys,'/',['Signal',13,'Generator1']],...
		'hide name',0,...
		'Peak','0.100000',...
		'Peak Range','5.000000',...
		'Freq','0.295000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads')
set_param([sys,'/',['Signal',13,'Generator1']],...
		'position',[10,108,40,142])


%     Subsystem  'control u'.

new_system([sys,'/','control u'])
set_param([sys,'/','control u'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','control u/x'])
set_param([sys,'/','control u/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['control u/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['control u/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','control u'],[90,65;125,65])
set_param([sys,'/','control u'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','control u'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','control u'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','control u'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','control u'],...
		'Mask Entries','T\/-1.5\/1.5\/''y-/r-/g-/w:/m*/ro/b+''\/')


%     Finished composite block 'control u'.

set_param([sys,'/','control u'],...
		'position',[415,156,445,194])

add_block('built-in/Mux',[sys,'/','Mux1'])
set_param([sys,'/','Mux1'],...
		'inputs','2',...
		'position',[340,155,370,190])

add_block('built-in/Sum',[sys,'/','Sum2'])
set_param([sys,'/','Sum2'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[135,237,155,273])


%     Subsystem  'Motor1'.

new_system([sys,'/','Motor1'])
set_param([sys,'/','Motor1'],'Location',[280,343,765,588])

add_block('built-in/Transfer Fcn',[sys,'/','Motor1/Load'])
set_param([sys,'/','Motor1/Load'],...
		'move name',0,...
		'Numerator','1',...
		'Denominator','[J b]',...
		'position',[215,83,270,137])

add_block('built-in/Gain',[sys,'/','Motor1/ k '])
set_param([sys,'/','Motor1/ k '],...
		'orientation',2,...
		'hide name',0,...
		'Gain','K',...
		'position',[220,158,265,202])

add_block('built-in/Integrator',[sys,'/','Motor1/Int3'])
set_param([sys,'/','Motor1/Int3'],...
		'hide name',0,...
		'Initial','.1',...
		'position',[415,82,450,138])

add_block('built-in/Transfer Fcn',[sys,'/','Motor1/Armature'])
set_param([sys,'/','Motor1/Armature'],...
		'move name',0,...
		'Numerator','K',...
		'Denominator','[L R]',...
		'position',[105,83,165,137])

add_block('built-in/Sum',[sys,'/','Motor1/Sum'])
set_param([sys,'/','Motor1/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[60,92,80,128])

add_block('built-in/Inport',[sys,'/','Motor1/in_1'])
set_param([sys,'/','Motor1/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Motor1/out_1'])
set_param([sys,'/','Motor1/out_1'],...
		'position',[470,100,490,120])

add_block('built-in/Dead Zone',[sys,'/','Motor1/Dead Zone'])
set_param([sys,'/','Motor1/Dead Zone'],...
		'Lower_value','-0.005',...
		'Upper_value','0.01',...
		'position',[320,97,350,123])
add_line([sys,'/','Motor1'],[355,110;410,110])
add_line([sys,'/','Motor1'],[275,110;315,110])
add_line([sys,'/','Motor1'],[170,110;210,110])
add_line([sys,'/','Motor1'],[215,180;45,180;55,120])
add_line([sys,'/','Motor1'],[85,110;100,110])
add_line([sys,'/','Motor1'],[40,100;55,100])
add_line([sys,'/','Motor1'],[455,110;465,110])
add_line([sys,'/','Motor1'],[385,110;385,180;270,180])
set_param([sys,'/','Motor1'],...
		'Mask Display','MOTOR')


%     Finished composite block 'Motor1'.

set_param([sys,'/','Motor1'],...
		'hide name',0,...
		'position',[350,227,420,283])

add_block('built-in/Look Up Table',[sys,'/',['Look-Up',13,'Table']])
set_param([sys,'/',['Look-Up',13,'Table']],...
		'hide name',0,...
		'Input_Values','edom',...
		'Output_Values','utab',...
		'Mask Display','Fuzzy',...
		'position',[220,233,270,277])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[130,17,150,53])


%     Subsystem  'Motor'.

new_system([sys,'/','Motor'])
set_param([sys,'/','Motor'],'Location',[280,343,765,588])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Load'])
set_param([sys,'/','Motor/Load'],...
		'move name',0,...
		'Numerator','1',...
		'Denominator','[J b]',...
		'position',[215,83,270,137])

add_block('built-in/Gain',[sys,'/','Motor/ k '])
set_param([sys,'/','Motor/ k '],...
		'orientation',2,...
		'hide name',0,...
		'Gain','K',...
		'position',[220,158,265,202])

add_block('built-in/Integrator',[sys,'/','Motor/Int3'])
set_param([sys,'/','Motor/Int3'],...
		'hide name',0,...
		'Initial','.1',...
		'position',[415,82,450,138])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Armature'])
set_param([sys,'/','Motor/Armature'],...
		'move name',0,...
		'Numerator','K',...
		'Denominator','[L R]',...
		'position',[105,83,165,137])

add_block('built-in/Sum',[sys,'/','Motor/Sum'])
set_param([sys,'/','Motor/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[60,92,80,128])

add_block('built-in/Inport',[sys,'/','Motor/in_1'])
set_param([sys,'/','Motor/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Motor/out_1'])
set_param([sys,'/','Motor/out_1'],...
		'position',[470,100,490,120])

add_block('built-in/Dead Zone',[sys,'/','Motor/Dead Zone'])
set_param([sys,'/','Motor/Dead Zone'],...
		'Lower_value','-0.005',...
		'Upper_value','0.01',...
		'position',[320,97,350,123])
add_line([sys,'/','Motor'],[355,110;410,110])
add_line([sys,'/','Motor'],[275,110;315,110])
add_line([sys,'/','Motor'],[170,110;210,110])
add_line([sys,'/','Motor'],[215,180;45,180;55,120])
add_line([sys,'/','Motor'],[85,110;100,110])
add_line([sys,'/','Motor'],[40,100;55,100])
add_line([sys,'/','Motor'],[455,110;465,110])
add_line([sys,'/','Motor'],[380,110;380,180;270,180])
set_param([sys,'/','Motor'],...
		'Mask Display','MOTOR')


%     Finished composite block 'Motor'.

set_param([sys,'/','Motor'],...
		'hide name',0,...
		'position',[345,7,415,63])

add_block('built-in/Gain',[sys,'/',' k 1'])
set_param([sys,'/',' k 1'],...
		'hide name',0,...
		'Gain','6',...
		'Mask Display','P',...
		'position',[220,13,265,57])


%     Subsystem  'angle'.

new_system([sys,'/','angle'])
set_param([sys,'/','angle'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','angle/x'])
set_param([sys,'/','angle/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','angle'],[90,65;125,65])
set_param([sys,'/','angle'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','angle'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','angle'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','angle'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','angle'],...
		'Mask Entries','T\/-.2\/0.2\/''y-/r-/g-/w:/m*/ro/b+''\/')


%     Finished composite block 'angle'.

set_param([sys,'/','angle'],...
		'position',[595,96,625,134])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','3',...
		'position',[535,98,565,132])


%     Subsystem  'Rules editor'.

new_system([sys,'/','Rules editor'])
set_param([sys,'/','Rules editor'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor'],...
		'Mask Display','proportional rules',...
		'Mask Type','Rule-base editor',...
		'Mask Dialogue','eval([''!notepad prop.rb'']);')


%     Finished composite block 'Rules editor'.

set_param([sys,'/','Rules editor'],...
		'hide name',0,...
		'position',[520,175,685,201])


%     Subsystem  'Rules editor3'.

new_system([sys,'/','Rules editor3'])
set_param([sys,'/','Rules editor3'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor3'],...
		'Mask Display','compensatory rules',...
		'Mask Type','Rule-base editor',...
		'Mask Dialogue','eval([''!notepad comp.rb'']);')


%     Finished composite block 'Rules editor3'.

set_param([sys,'/','Rules editor3'],...
		'hide name',0,...
		'position',[520,215,685,241])


%     Subsystem  'Rules editor1'.

new_system([sys,'/','Rules editor1'])
set_param([sys,'/','Rules editor1'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor1'],...
		'Mask Display','membership functions \n for error',...
		'Mask Type','Show membership functions')
set_param([sys,'/','Rules editor1'],...
		'Mask Dialogue','eval(''plot(edom,mgrade(edom,mfs(1:3,:)),''''w'''',edom,mgrade(edom,mfs(4:5,:)),''''g'''');'');')


%     Finished composite block 'Rules editor1'.

set_param([sys,'/','Rules editor1'],...
		'hide name',0,...
		'position',[520,255,685,291])


%     Subsystem  'Rules editor2'.

new_system([sys,'/','Rules editor2'])
set_param([sys,'/','Rules editor2'],'Location',[4,380,131,533])
set_param([sys,'/','Rules editor2'],...
		'Mask Display','membership functions \n for control input',...
		'Mask Type','Show membership functions')
set_param([sys,'/','Rules editor2'],...
		'Mask Dialogue','eval(''plot(udom,mgrade(udom,mfs(6:8,:)),''''w'''',udom,mgrade(udom,mfs(9:10,:)),''''g'''');'');')


%     Finished composite block 'Rules editor2'.

set_param([sys,'/','Rules editor2'],...
		'hide name',0,...
		'position',[520,305,685,341])
add_line(sys,[420,35;440,35;440,90;105,90;105,45;125,45])
add_line(sys,[155,35;215,35])
add_line(sys,[270,35;340,35])
add_line(sys,[425,255;445,255;445,304;110,304;110,265;130,265])
add_line(sys,[160,255;215,255])
add_line(sys,[275,255;345,255])
add_line(sys,[440,35;475,35;475,105;530,105])
add_line(sys,[445,255;475,255;475,115;530,115])
add_line(sys,[570,115;590,115])
add_line(sys,[45,125;75,125;75,245;130,245])
add_line(sys,[320,255;320,180;335,180])
add_line(sys,[315,35;315,165;335,165])
add_line(sys,[375,175;410,175])
add_line(sys,[75,125;75,25;125,25])
add_line(sys,[75,125;530,125])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
