function [ret,x0,str,ts,xts]=dcsimnl2(t,x,u,flag);
%DCSIMNL2	is the M-file description of the SIMULINK system named DCSIMNL2.
%	The block-diagram can be displayed by typing: DCSIMNL2.
%
%	SYS=DCSIMNL2(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes DCSIMNL2 to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling DCSIMNL2 with a FLAG of zero:
%	[SIZES]=DCSIMNL2([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[418,497,1002,715])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'T')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.2')
set_param(sys,'Relative error','1e-6')
set_param(sys,'Return vars',   '')

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[120,82,140,118])

add_block('built-in/To Workspace',[sys,'/','To Workspace2'])
set_param([sys,'/','To Workspace2'],...
		'hide name',0,...
		'mat-name','eprop',...
		'position',[185,21,250,49])

add_block('built-in/To Workspace',[sys,'/','To Workspace3'])
set_param([sys,'/','To Workspace3'],...
		'hide name',0,...
		'mat-name','uprop',...
		'position',[345,21,410,49])


%     Subsystem  'Motor'.

new_system([sys,'/','Motor'])
set_param([sys,'/','Motor'],'Location',[280,343,899,588])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Armature'])
set_param([sys,'/','Motor/Armature'],...
		'move name',0,...
		'Numerator','K',...
		'Denominator','[L R]',...
		'position',[105,83,165,137])

add_block('built-in/Sum',[sys,'/','Motor/Sum'])
set_param([sys,'/','Motor/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[60,92,80,128])

add_block('built-in/Inport',[sys,'/','Motor/in_1'])
set_param([sys,'/','Motor/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Motor/out_1'])
set_param([sys,'/','Motor/out_1'],...
		'position',[550,95,570,115])

add_block('built-in/Integrator',[sys,'/','Motor/Int3'])
set_param([sys,'/','Motor/Int3'],...
		'hide name',0,...
		'Initial','.1',...
		'position',[495,77,530,133])


%     Subsystem  'Motor/angle'.

new_system([sys,'/','Motor/angle'])
set_param([sys,'/','Motor/angle'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','Motor/angle/x'])
set_param([sys,'/','Motor/angle/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['Motor/angle/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['Motor/angle/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','Motor/angle'],[90,65;125,65])
set_param([sys,'/','Motor/angle'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','Motor/angle'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','Motor/angle'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','Motor/angle'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','Motor/angle'],...
		'Mask Entries','T\/-.02\/0.02\/''y-/g-/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'Motor/angle'.

set_param([sys,'/','Motor/angle'],...
		'position',[540,22,570,58])

add_block('built-in/Reset Integrator',[sys,'/',['Motor/Reset',13,'Integrator']])
set_param([sys,'/',['Motor/Reset',13,'Integrator']],...
		'position',[415,77,445,133])

add_block('built-in/Fcn',[sys,'/',['Motor/Ball hits ground.',13,'(Ball is dropping and',13,'below or on ground).']])
set_param([sys,'/',['Motor/Ball hits ground.',13,'(Ball is dropping and',13,'below or on ground).']],...
		'hide name',0,...
		'Expr','(u[1] < 0)',...
		'position',[315,130,355,150])

add_block('built-in/Constant',[sys,'/','Motor/Constant'])
set_param([sys,'/','Motor/Constant'],...
		'Value','0',...
		'position',[360,155,380,175])


%     Subsystem  'Motor/Hit Crossing'.

new_system([sys,'/','Motor/Hit Crossing'])
set_param([sys,'/','Motor/Hit Crossing'],'Location',[157,542,517,731])


%     Subsystem  'Motor/Hit Crossing/Hit crossing1'.

new_system([sys,'/','Motor/Hit Crossing/Hit crossing1'])
set_param([sys,'/','Motor/Hit Crossing/Hit crossing1'],'Location',[143,475,427,741])

add_block('built-in/Fcn',[sys,'/','Motor/Hit Crossing/Hit crossing1/Fcn1'])
set_param([sys,'/','Motor/Hit Crossing/Hit crossing1/Fcn1'],...
		'Expr','1-u',...
		'position',[115,105,155,125])

add_block('built-in/Reset Integrator',[sys,'/',['Motor/Hit Crossing/Hit crossing1/Resetable',13,'Integrator']])
set_param([sys,'/',['Motor/Hit Crossing/Hit crossing1/Resetable',13,'Integrator']],...
		'Initial','ic',...
		'Mask Display','1\n-\ns',...
		'Mask Type','Reset Integrator',...
		'Mask Dialogue','Reset Integrator|Initial value:')
set_param([sys,'/',['Motor/Hit Crossing/Hit crossing1/Resetable',13,'Integrator']],...
		'Mask Translate','ic=@1;',...
		'Mask Entries','0\/',...
		'position',[190,57,220,173])

add_block('built-in/Constant',[sys,'/','Motor/Hit Crossing/Hit crossing1/Constant'])
set_param([sys,'/','Motor/Hit Crossing/Hit crossing1/Constant'],...
		'Value','0',...
		'position',[125,145,145,165])

add_block('built-in/Gain',[sys,'/','Motor/Hit Crossing/Hit crossing1/Gain'])
set_param([sys,'/','Motor/Hit Crossing/Hit crossing1/Gain'],...
		'Gain','1/tol',...
		'position',[125,65,145,85])

add_block('built-in/Inport',[sys,'/','Motor/Hit Crossing/Hit crossing1/in_1'])
set_param([sys,'/','Motor/Hit Crossing/Hit crossing1/in_1'],...
		'position',[10,65,30,85])

add_block('built-in/Fcn',[sys,'/','Motor/Hit Crossing/Hit crossing1/Fcn'])
set_param([sys,'/','Motor/Hit Crossing/Hit crossing1/Fcn'],...
		'Expr','u<cross',...
		'position',[55,65,95,85])
add_line([sys,'/','Motor/Hit Crossing/Hit crossing1'],[100,75;120,75])
add_line([sys,'/','Motor/Hit Crossing/Hit crossing1'],[150,75;185,75])
add_line([sys,'/','Motor/Hit Crossing/Hit crossing1'],[35,75;50,75])
add_line([sys,'/','Motor/Hit Crossing/Hit crossing1'],[100,75;110,115])
add_line([sys,'/','Motor/Hit Crossing/Hit crossing1'],[150,155;185,155])
add_line([sys,'/','Motor/Hit Crossing/Hit crossing1'],[160,115;185,115])


%     Finished composite block 'Motor/Hit Crossing/Hit crossing1'.

set_param([sys,'/','Motor/Hit Crossing/Hit crossing1'],...
		'position',[715,100,755,130])

add_block('built-in/Constant',[sys,'/','Motor/Hit Crossing/Constant2'])
set_param([sys,'/','Motor/Hit Crossing/Constant2'],...
		'position',[175,100,195,120])

add_block('built-in/Sum',[sys,'/','Motor/Hit Crossing/Sum'])
set_param([sys,'/','Motor/Hit Crossing/Sum'],...
		'inputs','-+',...
		'position',[230,75,250,95])

add_block('built-in/Gain',[sys,'/','Motor/Hit Crossing/Gain'])
set_param([sys,'/','Motor/Hit Crossing/Gain'],...
		'Gain','1/tol',...
		'position',[240,35,260,55])

add_block('built-in/Constant',[sys,'/','Motor/Hit Crossing/Constant'])
set_param([sys,'/','Motor/Hit Crossing/Constant'],...
		'Value','0',...
		'position',[240,115,260,135])

add_block('built-in/Reset Integrator',[sys,'/',['Motor/Hit Crossing/Resetable',13,'Integrator']])
set_param([sys,'/',['Motor/Hit Crossing/Resetable',13,'Integrator']],...
		'Initial','ic',...
		'Mask Display','1\n-\ns',...
		'Mask Type','Reset Integrator',...
		'Mask Dialogue','Reset Integrator|Initial value:',...
		'Mask Translate','ic=@1;')
set_param([sys,'/',['Motor/Hit Crossing/Resetable',13,'Integrator']],...
		'Mask Entries','0\/',...
		'position',[305,27,335,143])

add_block('built-in/Relational Operator',[sys,'/',['Motor/Hit Crossing/Relational',13,'operator']])
set_param([sys,'/',['Motor/Hit Crossing/Relational',13,'operator']],...
		'Operator','<',...
		'position',[110,27,140,58])

add_block('built-in/Inport',[sys,'/','Motor/Hit Crossing/in_1'])
set_param([sys,'/','Motor/Hit Crossing/in_1'],...
		'position',[25,25,45,45])

add_block('built-in/Constant',[sys,'/','Motor/Hit Crossing/Constant1'])
set_param([sys,'/','Motor/Hit Crossing/Constant1'],...
		'Value','cross',...
		'position',[10,70,60,90])
add_line([sys,'/','Motor/Hit Crossing'],[255,85;300,85])
add_line([sys,'/','Motor/Hit Crossing'],[265,125;300,125])
add_line([sys,'/','Motor/Hit Crossing'],[50,35;105,35])
add_line([sys,'/','Motor/Hit Crossing'],[265,45;300,45])
add_line([sys,'/','Motor/Hit Crossing'],[65,80;70,80;70,50;105,50])
add_line([sys,'/','Motor/Hit Crossing'],[145,45;235,45])
add_line([sys,'/','Motor/Hit Crossing'],[180,45;180,80;225,80])
add_line([sys,'/','Motor/Hit Crossing'],[200,110;200,90;225,90])
set_param([sys,'/','Motor/Hit Crossing'],...
		'Mask Display','plot(-0.2,-0.2,3.45,1.2,dvec,abs(cos(dvec)),[.6 2.5],[0 0])',...
		'Mask Type','Crossing')
set_param([sys,'/','Motor/Hit Crossing'],...
		'Mask Dialogue','Causes simulation to take smaller steps at the crossing value (for instance, near a discontinuity). |Crossing Value:|Tol: (typically twice the simulation tol)')
set_param([sys,'/','Motor/Hit Crossing'],...
		'Mask Translate','cross=@1; tol=@2;dvec=-.3:.03:(pi+.3);')
set_param([sys,'/','Motor/Hit Crossing'],...
		'Mask Help','This block is used to cause the simulator to take smaller steps near a crossing point.  It uses a resetable integrator to accomplish this.  Systems with disontinuities can be more accurately modeled with this block.')
set_param([sys,'/','Motor/Hit Crossing'],...
		'Mask Entries','0\/1e-6\/')


%     Finished composite block 'Motor/Hit Crossing'.

set_param([sys,'/','Motor/Hit Crossing'],...
		'position',[520,151,555,189])

add_block('built-in/Look Up Table',[sys,'/',['Motor/Coulombic',13,'Friction']])
set_param([sys,'/',['Motor/Coulombic',13,'Friction']],...
		'orientation',2,...
		'Input_Values','[-1,0,0,1]',...
		'Output_Values','[-gain-ini -ini ini gain+ini]')
set_param([sys,'/',['Motor/Coulombic',13,'Friction']],...
		'Mask Display','plot([-1 0 0 1],[-gain-ini, -ini, ini, gain+ini],[-1 1],[0 0],[0 0],[-x,x])',...
		'Mask Type','Coulombic Friction')
set_param([sys,'/',['Motor/Coulombic',13,'Friction']],...
		'Mask Dialogue','Coulombic Friction\ny = sign(x) * (Gain * abs(x) + Offset)|Offset discontinuity at zero:|Gain:',...
		'Mask Translate','ini=@1;gain=@2;x=max(ini,gain+ini);')
set_param([sys,'/',['Motor/Coulombic',13,'Friction']],...
		'Mask Help','This block has a discontinuity\nat zero and a linear gain afterward.\ny= sign(x)*(Gain*abs(x)+Offset)',...
		'Mask Entries','0\/b\/',...
		'position',[280,12,310,38])

add_block('built-in/Gain',[sys,'/','Motor/ k '])
set_param([sys,'/','Motor/ k '],...
		'orientation',2,...
		'hide name',0,...
		'Gain','K',...
		'position',[260,198,305,242])

add_block('built-in/Gain',[sys,'/','Motor/ k 1'])
set_param([sys,'/','Motor/ k 1'],...
		'hide name',0,...
		'Gain','1/J',...
		'position',[330,73,375,117])

add_block('built-in/Sum',[sys,'/','Motor/Sum1'])
set_param([sys,'/','Motor/Sum1'],...
		'hide name',0,...
		'inputs','-+',...
		'position',[185,82,205,118])

add_block('built-in/Product',[sys,'/','Motor/Product'])
set_param([sys,'/','Motor/Product'],...
		'position',[225,113,255,137])


%     Subsystem  'Motor/Sign'.

new_system([sys,'/','Motor/Sign'])
set_param([sys,'/','Motor/Sign'],'Location',[159,417,467,586])

add_block('built-in/Outport',[sys,'/','Motor/Sign/out_1'])
set_param([sys,'/','Motor/Sign/out_1'],...
		'position',[265,70,285,90])

add_block('built-in/Inport',[sys,'/','Motor/Sign/in_1'])
set_param([sys,'/','Motor/Sign/in_1'],...
		'position',[35,30,55,50])

add_block('built-in/Relational Operator',[sys,'/',['Motor/Sign/Relational',13,'Operator']])
set_param([sys,'/',['Motor/Sign/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[140,32,170,63])

add_block('built-in/Sum',[sys,'/','Motor/Sign/Sum'])
set_param([sys,'/','Motor/Sign/Sum'],...
		'inputs','+-',...
		'position',[215,64,235,91])

add_block('built-in/Relational Operator',[sys,'/',['Motor/Sign/Relational',13,'Operator1']])
set_param([sys,'/',['Motor/Sign/Relational',13,'Operator1']],...
		'Operator','<',...
		'position',[140,92,170,123])

add_block('built-in/Constant',[sys,'/','Motor/Sign/Constant'])
set_param([sys,'/','Motor/Sign/Constant'],...
		'Value','0',...
		'position',[65,105,85,125])
add_line([sys,'/','Motor/Sign'],[60,40;135,40])
add_line([sys,'/','Motor/Sign'],[95,40;95,100;135,100])
add_line([sys,'/','Motor/Sign'],[90,115;135,115])
add_line([sys,'/','Motor/Sign'],[110,115;110,55;135,55])
add_line([sys,'/','Motor/Sign'],[175,110;185,110;185,85;210,85])
add_line([sys,'/','Motor/Sign'],[175,50;185,50;185,70;210,70])
add_line([sys,'/','Motor/Sign'],[240,80;260,80])
set_param([sys,'/','Motor/Sign'],...
		'Mask Display','plot(-50,-50,50,50,[-50,50],[0,0],[0,0],[-50,50],[-40,0],[-30,-30],[0,40],[30,30])',...
		'Mask Type','Sign',...
		'Mask Dialogue','y = sign(x)')
set_param([sys,'/','Motor/Sign'],...
		'Mask Help','Sign Function:\n\t\t\ty = 1 if x > 0\n\t\t\ty = 0 if x = 0\n\t\t\ty = -1 if x < 0')


%     Finished composite block 'Motor/Sign'.

set_param([sys,'/','Motor/Sign'],...
		'position',[160,157,190,183])


%     Subsystem  'Motor/Sign1'.

new_system([sys,'/','Motor/Sign1'])
set_param([sys,'/','Motor/Sign1'],'Location',[159,417,467,586])

add_block('built-in/Constant',[sys,'/','Motor/Sign1/Constant'])
set_param([sys,'/','Motor/Sign1/Constant'],...
		'Value','0',...
		'position',[65,105,85,125])

add_block('built-in/Relational Operator',[sys,'/',['Motor/Sign1/Relational',13,'Operator1']])
set_param([sys,'/',['Motor/Sign1/Relational',13,'Operator1']],...
		'Operator','<',...
		'position',[140,92,170,123])

add_block('built-in/Sum',[sys,'/','Motor/Sign1/Sum'])
set_param([sys,'/','Motor/Sign1/Sum'],...
		'inputs','+-',...
		'position',[215,64,235,91])

add_block('built-in/Relational Operator',[sys,'/',['Motor/Sign1/Relational',13,'Operator']])
set_param([sys,'/',['Motor/Sign1/Relational',13,'Operator']],...
		'Operator','>',...
		'position',[140,32,170,63])

add_block('built-in/Inport',[sys,'/','Motor/Sign1/in_1'])
set_param([sys,'/','Motor/Sign1/in_1'],...
		'position',[35,30,55,50])

add_block('built-in/Outport',[sys,'/','Motor/Sign1/out_1'])
set_param([sys,'/','Motor/Sign1/out_1'],...
		'position',[265,70,285,90])
add_line([sys,'/','Motor/Sign1'],[240,80;260,80])
add_line([sys,'/','Motor/Sign1'],[175,50;185,50;185,70;210,70])
add_line([sys,'/','Motor/Sign1'],[175,110;185,110;185,85;210,85])
add_line([sys,'/','Motor/Sign1'],[90,115;135,115])
add_line([sys,'/','Motor/Sign1'],[110,115;110,55;135,55])
add_line([sys,'/','Motor/Sign1'],[60,40;135,40])
add_line([sys,'/','Motor/Sign1'],[95,40;95,100;135,100])
set_param([sys,'/','Motor/Sign1'],...
		'Mask Display','plot(-50,-50,50,50,[-50,50],[0,0],[0,0],[-50,50],[-40,0],[-30,-30],[0,40],[30,30])',...
		'Mask Type','Sign',...
		'Mask Dialogue','y = sign(x)')
set_param([sys,'/','Motor/Sign1'],...
		'Mask Help','Sign Function:\n\t\t\ty = 1 if x > 0\n\t\t\ty = 0 if x = 0\n\t\t\ty = -1 if x < 0')


%     Finished composite block 'Motor/Sign1'.

set_param([sys,'/','Motor/Sign1'],...
		'position',[125,187,155,213])

add_block('built-in/Saturation',[sys,'/','Motor/Saturation'])
set_param([sys,'/','Motor/Saturation'],...
		'Lower Limit','0',...
		'Upper Limit','inf',...
		'position',[215,188,245,212])

add_block('built-in/Product',[sys,'/','Motor/Product1'])
set_param([sys,'/','Motor/Product1'],...
		'position',[270,78,300,102])
add_line([sys,'/','Motor'],[255,220;45,220;55,120])
add_line([sys,'/','Motor'],[85,110;100,110])
add_line([sys,'/','Motor'],[40,100;55,100])
add_line([sys,'/','Motor'],[535,105;545,105])
add_line([sys,'/','Motor'],[380,95;410,85])
add_line([sys,'/','Motor'],[385,165;395,165;395,125;410,125])
add_line([sys,'/','Motor'],[450,105;490,105])
add_line([sys,'/','Motor'],[465,105;465,25;315,25])
add_line([sys,'/','Motor'],[465,105;465,220;310,220])
add_line([sys,'/','Motor'],[465,170;515,170])
add_line([sys,'/','Motor'],[360,140;380,140;380,105;410,105])
add_line([sys,'/','Motor'],[170,110;180,110])
add_line([sys,'/','Motor'],[275,25;165,25;165,90;180,90])
add_line([sys,'/','Motor'],[170,110;175,110;155,170])
add_line([sys,'/','Motor'],[195,170;220,130])
add_line([sys,'/','Motor'],[210,100;220,120])
add_line([sys,'/','Motor'],[260,125;270,125;270,155;200,155;200,245;105,245;105,200;120,200])
add_line([sys,'/','Motor'],[160,200;210,200])
add_line([sys,'/','Motor'],[250,200;255,200;255,180;260,180;265,95])
add_line([sys,'/','Motor'],[210,100;240,100;240,85;265,85])
add_line([sys,'/','Motor'],[305,90;325,105;325,95])
add_line([sys,'/','Motor'],[260,180;300,180;310,140])
add_line([sys,'/','Motor'],[250,200;255,200;255,180;415,180;415,165;450,165;450,40;535,40])
set_param([sys,'/','Motor'],...
		'Mask Display','MOTOR')


%     Finished composite block 'Motor'.

set_param([sys,'/','Motor'],...
		'hide name',0,...
		'position',[335,72,405,128])

add_block('built-in/Gain',[sys,'/',' k 1'])
set_param([sys,'/',' k 1'],...
		'hide name',0,...
		'Gain','6',...
		'Mask Display','P',...
		'position',[210,78,255,122])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'hide name',0,...
		'Peak','0.100000',...
		'Peak Range','5.000000',...
		'Freq','0.295000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[20,73,65,107])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[485,91,515,124])


%     Subsystem  'angle'.

new_system([sys,'/','angle'])
set_param([sys,'/','angle'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','angle/x'])
set_param([sys,'/','angle/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','angle'],[90,65;125,65])
set_param([sys,'/','angle'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','angle'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','angle'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','angle'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','angle'],...
		'Mask Entries','T\/-.2\/0.2\/''y-/g-/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'angle'.

set_param([sys,'/','angle'],...
		'position',[545,92,575,128])

add_block('built-in/To Workspace',[sys,'/','To Workspace  '])
set_param([sys,'/','To Workspace  '],...
		'hide name',0,...
		'mat-name','t',...
		'position',[70,8,105,42])

add_block('built-in/Clock',[sys,'/','Clock'])
set_param([sys,'/','Clock'],...
		'position',[20,8,50,42])
add_line(sys,[410,100;430,100;430,165;95,165;95,110;115,110])
add_line(sys,[145,100;155,100;155,35;180,35])
add_line(sys,[145,100;205,100])
add_line(sys,[260,100;330,100])
add_line(sys,[305,100;305,35;340,35])
add_line(sys,[70,90;115,90])
add_line(sys,[55,25;65,25])
add_line(sys,[520,110;540,110])
add_line(sys,[430,100;480,100])
add_line(sys,[80,90;80,185;460,185;460,115;480,115])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
