function [ret,x0,str,ts,xts]=nicep(t,x,u,flag);
%NICEP	is the M-file description of the SIMULINK system named NICEP.
%	The block-diagram can be displayed by typing: NICEP.
%
%	SYS=NICEP(T,X,U,FLAG) returns depending on FLAG certain
%	system values given time point, T, current state vector, X,
%	and input vector, U.
%	FLAG is used to indicate the type of output to be returned in SYS.
%
%	Setting FLAG=1 causes NICEP to return state derivatives, FLAG=2
%	discrete states, FLAG=3 system outputs and FLAG=4 next sample
%	time. For more information and other options see SFUNC.
%
%	Calling NICEP with a FLAG of zero:
%	[SIZES]=NICEP([],[],[],0),  returns a vector, SIZES, which
%	contains the sizes of the state vector and other parameters.
%		SIZES(1) number of states
%		SIZES(2) number of discrete states
%		SIZES(3) number of outputs
%		SIZES(4) number of inputs
%		SIZES(5) number of roots (currently unsupported)
%		SIZES(6) direct feedthrough flag
%		SIZES(7) number of sample times
%
%	For the definition of other parameters in SIZES, see SFUNC.
%	See also, TRIM, LINMOD, LINSIM, EULER, RK23, RK45, ADAMS, GEAR.

% Note: This M-file is only used for saving graphical information;
%       after the model is loaded into memory an internal model
%       representation is used.

% the system will take on the name of this mfile:
sys = mfilename;
new_system(sys)
simver(1.3)
if (0 == (nargin + nargout))
     set_param(sys,'Location',[418,422,1002,715])
     open_system(sys)
end;
set_param(sys,'algorithm',     'RK-45')
set_param(sys,'Start time',    '0.0')
set_param(sys,'Stop time',     'T')
set_param(sys,'Min step size', '0.01')
set_param(sys,'Max step size', '0.2')
set_param(sys,'Relative error','1e-6')
set_param(sys,'Return vars',   '')


%     Subsystem  'control u'.

new_system([sys,'/','control u'])
set_param([sys,'/','control u'],'Location',[0,59,274,252])

add_block('built-in/Inport',[sys,'/','control u/x'])
set_param([sys,'/','control u/x'],...
		'position',[65,55,85,75])

add_block('built-in/S-Function',[sys,'/',['control u/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['control u/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])
add_line([sys,'/','control u'],[90,65;125,65])
set_param([sys,'/','control u'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','control u'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','control u'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','control u'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','control u'],...
		'Mask Entries','T\/-1.5\/1.5\/''y-/r-/g-/w:/m*/ro/b+''\/')


%     Finished composite block 'control u'.

set_param([sys,'/','control u'],...
		'position',[355,21,385,59])

add_block('built-in/Sum',[sys,'/','Sum1'])
set_param([sys,'/','Sum1'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[115,107,135,143])


%     Subsystem  'Motor'.

new_system([sys,'/','Motor'])
set_param([sys,'/','Motor'],'Location',[280,343,765,588])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Load'])
set_param([sys,'/','Motor/Load'],...
		'move name',0,...
		'Numerator','1',...
		'Denominator','[J b]',...
		'position',[215,83,270,137])

add_block('built-in/Integrator',[sys,'/','Motor/Int3'])
set_param([sys,'/','Motor/Int3'],...
		'hide name',0,...
		'Initial','.1',...
		'position',[415,82,450,138])

add_block('built-in/Transfer Fcn',[sys,'/','Motor/Armature'])
set_param([sys,'/','Motor/Armature'],...
		'move name',0,...
		'Numerator','K',...
		'Denominator','[L R]',...
		'position',[105,83,165,137])

add_block('built-in/Sum',[sys,'/','Motor/Sum'])
set_param([sys,'/','Motor/Sum'],...
		'hide name',0,...
		'inputs','+-',...
		'position',[60,92,80,128])

add_block('built-in/Inport',[sys,'/','Motor/in_1'])
set_param([sys,'/','Motor/in_1'],...
		'position',[15,90,35,110])

add_block('built-in/Outport',[sys,'/','Motor/out_1'])
set_param([sys,'/','Motor/out_1'],...
		'position',[470,100,490,120])

add_block('built-in/Dead Zone',[sys,'/','Motor/Dead Zone'])
set_param([sys,'/','Motor/Dead Zone'],...
		'Lower_value','-0.005',...
		'Upper_value','0.01',...
		'position',[310,97,340,123])

add_block('built-in/Gain',[sys,'/','Motor/ k '])
set_param([sys,'/','Motor/ k '],...
		'orientation',2,...
		'hide name',0,...
		'Gain','K',...
		'position',[215,153,260,197])
add_line([sys,'/','Motor'],[345,110;410,110])
add_line([sys,'/','Motor'],[275,110;305,110])
add_line([sys,'/','Motor'],[170,110;210,110])
add_line([sys,'/','Motor'],[210,175;45,175;55,120])
add_line([sys,'/','Motor'],[85,110;100,110])
add_line([sys,'/','Motor'],[40,100;55,100])
add_line([sys,'/','Motor'],[455,110;465,110])
add_line([sys,'/','Motor'],[380,110;380,175;265,175])
set_param([sys,'/','Motor'],...
		'Mask Display','MOTOR')


%     Finished composite block 'Motor'.

set_param([sys,'/','Motor'],...
		'hide name',0,...
		'position',[330,97,400,153])

add_block('built-in/Gain',[sys,'/',' k 1'])
set_param([sys,'/',' k 1'],...
		'hide name',0,...
		'Gain','6',...
		'Mask Display','P',...
		'position',[205,103,250,147])

add_block('built-in/Signal Generator',[sys,'/',['Signal',13,'Generator']])
set_param([sys,'/',['Signal',13,'Generator']],...
		'hide name',0,...
		'Peak','0.100000',...
		'Peak Range','5.000000',...
		'Freq','0.295000',...
		'Freq Range','5.000000',...
		'Wave','Sqr',...
		'Units','Rads',...
		'position',[15,98,60,132])

add_block('built-in/Mux',[sys,'/','Mux'])
set_param([sys,'/','Mux'],...
		'inputs','2',...
		'position',[480,116,510,149])


%     Subsystem  'angle'.

new_system([sys,'/','angle'])
set_param([sys,'/','angle'],'Location',[0,59,274,252])

add_block('built-in/S-Function',[sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']])
set_param([sys,'/',['angle/S-function',13,'M-file which plots',13,'lines',13,'']],...
		'function name','sfuny',...
		'parameters','ax, color,dt',...
		'position',[130,55,180,75])

add_block('built-in/Inport',[sys,'/','angle/x'])
set_param([sys,'/','angle/x'],...
		'position',[65,55,85,75])
add_line([sys,'/','angle'],[90,65;125,65])
set_param([sys,'/','angle'],...
		'Mask Display','plot(0,0,100,100,[90,10,10,10,90,90,10],[65,65,90,40,40,90,90],[90,78,69,54,40,31,25,10],[77,60,48,46,56,75,81,84])',...
		'Mask Type','Graph scope.')
set_param([sys,'/','angle'],...
		'Mask Dialogue','Graph scope using MATLAB graph window.\nEnter plotting ranges and line type.|Time range:|y-min:|y-max:|Line type (rgbw-:*). Seperate each plot by ''/'':')
set_param([sys,'/','angle'],...
		'Mask Translate','color = @4; ax = [0, @1, @2, @3]; dt = -1;')
set_param([sys,'/','angle'],...
		'Mask Help','This block plots to the MATLAB graph window and can be used as an improved version of the Scope block. Look at the m-file sfuny.m to see how it works. This block can take scalar or vector input signal.')
set_param([sys,'/','angle'],...
		'Mask Entries','T\/-.2\/0.2\/''y-/g-/c-./w:/m*/ro/b+''\/')


%     Finished composite block 'angle'.

set_param([sys,'/','angle'],...
		'position',[540,117,570,153])
add_line(sys,[405,125;425,125;425,190;90,190;90,135;110,135])
add_line(sys,[140,125;200,125])
add_line(sys,[255,125;325,125])
add_line(sys,[65,115;110,115])
add_line(sys,[515,135;535,135])
add_line(sys,[425,125;475,125])
add_line(sys,[75,115;75,210;455,210;455,140;475,140])
add_line(sys,[300,125;300,40;350,40])

drawnow

% Return any arguments.
if (nargin | nargout)
	% Must use feval here to access system in memory
	if (nargin > 3)
		if (flag == 0)
			eval(['[ret,x0,str,ts,xts]=',sys,'(t,x,u,flag);'])
		else
			eval(['ret =', sys,'(t,x,u,flag);'])
		end
	else
		[ret,x0,str,ts,xts] = feval(sys);
	end
else
	drawnow % Flash up the model and execute load callback
end
